## ----echo=FALSE----------------------------------------------------------
set.seed(40)

## ------------------------------------------------------------------------
library(scrm)
sum_stats <- scrm('5 1 -r 1.5 100 -T')

## ------------------------------------------------------------------------
library(ape)
trees <- read.tree(text = paste(sum_stats$trees[[1]], collapse = ""))

## ---- fig.align='center'-------------------------------------------------
plot(trees, no.margin = TRUE)

